cliquer: Routines for clique searching
======================================

Description
-----------

Cliquer is a set of C routines for finding cliques in an arbitrary
weighted graph. It uses an exact branch-and-bound algorithm
developed by Patric Östergård.

License
-------

GNU General Public License v2


Upstream Contact
----------------

Cliquer was mainly written by Sampo Niskanen, sampo.niskanenQiki.fi
(Q=@).

https://users.aalto.fi/~pat/cliquer.html

Patches
-------

-  minor config updates (v1.22)
-  autotoolized - see https://github.com/dimpase/autocliquer (v1.21)
